package com.ruoyi.business.service.impl;

import java.util.List;
import com.ruoyi.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.business.mapper.HwTenantMapper;
import com.ruoyi.business.domain.HwTenant;
import com.ruoyi.business.service.IHwTenantService;

/**
 * 租户信息Service业务层处理
 * 
 * @author xins
 * @date 2023-09-04
 */
@Service
public class HwTenantServiceImpl implements IHwTenantService 
{
    @Autowired
    private HwTenantMapper hwTenantMapper;

    /**
     * 查询租户信息
     * 
     * @param tenantId 租户信息主键
     * @return 租户信息
     */
    @Override
    public HwTenant selectHwTenantByTenantId(Long tenantId)
    {
        return hwTenantMapper.selectHwTenantByTenantId(tenantId);
    }

    /**
     * 查询租户信息列表
     * 
     * @param hwTenant 租户信息
     * @return 租户信息
     */
    @Override
    public List<HwTenant> selectHwTenantList(HwTenant hwTenant)
    {
        return hwTenantMapper.selectHwTenantList(hwTenant);
    }

    /**
     * 新增租户信息
     * 
     * @param hwTenant 租户信息
     * @return 结果
     */
    @Override
    public int insertHwTenant(HwTenant hwTenant)
    {
        hwTenant.setCreateTime(DateUtils.getNowDate());
        return hwTenantMapper.insertHwTenant(hwTenant);
    }

    /**
     * 修改租户信息
     * 
     * @param hwTenant 租户信息
     * @return 结果
     */
    @Override
    public int updateHwTenant(HwTenant hwTenant)
    {
        hwTenant.setUpdateTime(DateUtils.getNowDate());
        return hwTenantMapper.updateHwTenant(hwTenant);
    }

    /**
     * 批量删除租户信息
     * 
     * @param tenantIds 需要删除的租户信息主键
     * @return 结果
     */
    @Override
    public int deleteHwTenantByTenantIds(Long[] tenantIds)
    {
        return hwTenantMapper.deleteHwTenantByTenantIds(tenantIds);
    }

    /**
     * 删除租户信息信息
     * 
     * @param tenantId 租户信息主键
     * @return 结果
     */
    @Override
    public int deleteHwTenantByTenantId(Long tenantId)
    {
        return hwTenantMapper.deleteHwTenantByTenantId(tenantId);
    }
}
